/****************************************************************************
** $Id: qwindow.h,v 2.1 1997/08/06 15:05:49 hanord Exp $
**
** Definition of QWindow class
**
** Created : 931112
**
** Copyright (C) 1992-1997 Troll Tech AS.  All rights reserved.
**
** This file is part of the free edition of Qt 1.31.
**
** See the file LICENSE included in the distribution for the usage
** and distribution terms, or http://www.troll.no/qt/license.html.
**
** IMPORTANT NOTE: You may NOT copy this file or any part of it into
** your own programs or libraries.
**
** (This file differs from the one in the commercial edition of Qt
** only by this comment.)
**
*****************************************************************************/

#ifndef QWINDOW_H
#define QWINDOW_H

#include "qwidget.h"


class QWindow : public QWidget			// window widget class
{
    Q_OBJECT
public:
    QWindow( QWidget *parent=0, const char *name=0, WFlags f=0 );
   ~QWindow();

private:	// Disabled copy constructor and operator=
    QWindow( const QWindow & ) {}
    QWindow &operator=( const QWindow & ) { return *this; }
};


#endif // QWINDOW_H
